TaoData

Dependencies
=========
python 3.x


Installation
====

- 方式1：pip install taodata
- 方式2：python setup.py install
- 方式3：访问[https://pypi.python.org/pypi/taodata/](https://pypi.python.org/pypi/taodata/)下载安装


Upgrade
=======

	pip install taodata --upgrade

Quick Start
======



更多文档
========

[https://taodata.pro](https://taodata.pro)


Change Logs
-----------

0.1.0 2022/02/24
===

- 创建第一个版本
